from setuptools import setup, find_packages

setup(
    name="common-details",
    version="1.0.0",
    packages=find_packages(),
    install_requires=[],
    author="sheshadri",
    description="Common details library",
    # license="MIT" 
)
